@@ -19,8 +19,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "doomfeatures.h"
-
 #include "d_event.h"
 #include "d_loop.h"
 #include "d_ticcmd.h"
@@ -183,14 +181,11 @@ static boolean BuildNewTic(void)
     memset(&cmd, 0, sizeof(ticcmd_t));
     loop_interface->BuildTiccmd(&cmd, maketic);
 
-#ifdef FEATURE_MULTIPLAYER
-
     if (net_client_connected)
     {
         NET_CL_SendTiccmd(&cmd, maketic);
     }
 
-#endif
     ticdata[maketic % BACKUPTICS].cmds[localplayer] = cmd;
     ticdata[maketic % BACKUPTICS].ingame[localplayer] = true;
 
@@ -218,15 +213,11 @@ void NetUpdate (void)
     if (singletics)
         return;
 
-#ifdef FEATURE_MULTIPLAYER
-
     // Run network subsystems
 
     NET_CL_Run();
     NET_SV_Run();
 
-#endif
-
     // check time
     nowtime = GetAdjustedTime() / ticdup;
     newtics = nowtime - lasttime;
@@ -452,8 +443,6 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
 
     player_class = connect_data->player_class;
 
-#ifdef FEATURE_MULTIPLAYER
-
     //!
     // @category net
     //
@@ -535,7 +524,6 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
 
         result = true;
     }
-#endif
 
     return result;
 }
@@ -548,10 +536,8 @@ boolean D_InitNetGame(net_connect_data_t *connect_data)
 //
 void D_QuitNetGame (void)
 {
-#ifdef FEATURE_MULTIPLAYER
     NET_SV_Shutdown();
     NET_CL_Disconnect();
-#endif
 }
 
 static int GetLowTic(void)
@@ -560,7 +546,6 @@ static int GetLowTic(void)
 
     lowtic = maketic;
 
-#ifdef FEATURE_MULTIPLAYER
     if (net_client_connected)
     {
         if (drone || recvtic < lowtic)
@@ -568,7 +553,6 @@ static int GetLowTic(void)
             lowtic = recvtic;
         }
     }
-#endif
 
     return lowtic;
 }
