@@ -24,6 +24,7 @@
 #include "z_zone.h"
 
 #include "deh_main.h"
+#include "i_input.h"
 #include "i_swap.h"
 #include "i_video.h"
 
@@ -560,6 +561,21 @@ char HU_dequeueChatChar(void)
     return c;
 }
 
+static void StartChatInput(int dest)
+{
+    chat_on = true;
+    HUlib_resetIText(&w_chat);
+    HU_queueChatChar(HU_BROADCAST);
+
+    I_StartTextInput(0, 8, SCREENWIDTH, 16);
+}
+
+static void StopChatInput(void)
+{
+    chat_on = false;
+    I_StopTextInput();
+}
+
 boolean HU_Responder(event_t *ev)
 {
 
@@ -600,9 +616,8 @@ boolean HU_Responder(event_t *ev)
 	}
 	else if (netgame && ev->data2 == key_multi_msg)
 	{
-	    eatkey = chat_on = true;
-	    HUlib_resetIText(&w_chat);
-	    HU_queueChatChar(HU_BROADCAST);
+	    eatkey = true;
+            StartChatInput(HU_BROADCAST);
 	}
 	else if (netgame && numplayers > 2)
 	{
@@ -612,9 +627,8 @@ boolean HU_Responder(event_t *ev)
 		{
 		    if (playeringame[i] && i!=consoleplayer)
 		    {
-			eatkey = chat_on = true;
-			HUlib_resetIText(&w_chat);
-			HU_queueChatChar(i+1);
+			eatkey = true;
+                        StartChatInput(i + 1);
 			break;
 		    }
 		    else if (i == consoleplayer)
@@ -645,37 +659,37 @@ boolean HU_Responder(event_t *ev)
 		return false;
 	    // fprintf(stderr, "got here\n");
 	    macromessage = chat_macros[c];
-	    
+
 	    // kill last message with a '\n'
 	    HU_queueChatChar(KEY_ENTER); // DEBUG!!!
-	    
+
 	    // send the macro message
 	    while (*macromessage)
 		HU_queueChatChar(*macromessage++);
 	    HU_queueChatChar(KEY_ENTER);
-	    
+
             // leave chat mode and notify that it was sent
-            chat_on = false;
+            StopChatInput();
             M_StringCopy(lastmessage, chat_macros[c], sizeof(lastmessage));
             plr->message = lastmessage;
             eatkey = true;
 	}
 	else
 	{
-            c = ev->data2;
+            c = ev->data3;
 
 	    eatkey = HUlib_keyInIText(&w_chat, c);
 	    if (eatkey)
 	    {
 		// static unsigned char buf[20]; // DEBUG
 		HU_queueChatChar(c);
-		
+
 		// M_snprintf(buf, sizeof(buf), "KEY: %d => %d", ev->data1, c);
 		//        plr->message = buf;
 	    }
 	    if (c == KEY_ENTER)
 	    {
-		chat_on = false;
+		StopChatInput();
                 if (w_chat.l.len)
                 {
                     M_StringCopy(lastmessage, w_chat.l.l, sizeof(lastmessage));
@@ -683,10 +697,11 @@ boolean HU_Responder(event_t *ev)
                 }
 	    }
 	    else if (c == KEY_ESCAPE)
-		chat_on = false;
+	    {
+                StopChatInput();
+            }
 	}
     }
 
     return eatkey;
-
 }
