@@ -677,12 +677,14 @@ static void PadRejectArray(byte *array, unsigned int len)
 
     unsigned int rejectpad[4] =
     {
-        ((totallines * 4 + 3) & ~3) + 24,     // Size
+        0,                                    // Size
         0,                                    // Part of z_zone block header
         50,                                   // PU_LEVEL
         0x1d4a11                              // DOOM_CONST_ZONEID
     };
 
+    rejectpad[0] = ((totallines * 4 + 3) & ~3) + 24;
+
     // Copy values from rejectpad into the destination array.
 
     dest = array;
