@@ -54,7 +54,7 @@ fixed_t FixedDiv(fixed_t a, fixed_t b)
     {
 	int64_t result;
 
-	result = ((int64_t) a << 16) / b;
+	result = ((int64_t) a << FRACBITS) / b;
 
 	return (fixed_t) result;
     }
