@@ -31,9 +31,11 @@
 #include "doomstat.h"
 
 #include "dstrings.h"
-#include "doomfeatures.h"
 #include "sounds.h"
 
+#include "txt_main.h"
+#include "txt_io.h"
+
 #include "d_iwad.h"
 
 #include "z_zone.h"
@@ -56,6 +58,7 @@
 #include "p_dialog.h" // haleyjd [STRIFE]
 
 #include "i_endoom.h"
+#include "i_input.h"
 #include "i_joystick.h"
 #include "i_system.h"
 #include "i_timer.h"
@@ -144,6 +147,7 @@ char		mapdir[1024];           // directory of development maps
 int             show_endoom = 1;
 int             show_diskicon = 1;
 int             graphical_startup = 1;
+static boolean  using_text_startup;
 
 // If true, startup has completed and the main game loop has started.
 
@@ -398,6 +402,7 @@ void D_BindVariables(void)
 
     M_ApplyPlatformDefaults();
 
+    I_BindInputVariables();
     I_BindVideoVariables();
     I_BindJoystickVariables();
     I_BindSoundVariables();
@@ -419,9 +424,7 @@ void D_BindVariables(void)
     key_multi_msgplayer[6] = '7';
     key_multi_msgplayer[7] = '8';
 
-#ifdef FEATURE_MULTIPLAYER
     NET_BindVariables();
-#endif
 
     // haleyjd 08/29/10: [STRIFE]
     // * Added voice volume
@@ -508,7 +511,6 @@ void D_DoomLoop (void)
 
     if (!showintro)
     {
-        I_SetWindowTitle(gamedescription);
         I_InitGraphics();
     }
 
@@ -920,7 +922,27 @@ void D_SetGameDescription(void)
 }
 
 //      print title for every printed line
-char            title[128];
+static char title[128] = "";
+
+static void InitTitleString(void)
+{
+    switch (gameversion)
+    {
+    case exe_strife_1_2:
+        DEH_snprintf(title, sizeof(title), "                      "
+                                           "STRIFE:  Quest for the Sigil v1.2"
+                                           "                                  "
+                                           );
+        break;
+    case exe_strife_1_31:
+    default:
+        DEH_snprintf(title, sizeof(title), "                      "
+                                           "STRIFE:  Quest for the Sigil v1.31"
+                                           "                                 "
+                                           );
+        break;
+    }
+}
 
 static boolean D_AddFile(char *filename)
 {
@@ -1080,6 +1102,85 @@ static void D_Endoom(void)
     I_Endoom(endoom);
 }
 
+//
+// D_GetCursorColumn
+//
+static int D_GetCursorColumn(void)
+{
+    int x, y;
+    TXT_GetXY(&x, &y);
+    return x;
+}
+
+//
+// D_GetCursorRow
+//
+static int D_GetCursorRow(void)
+{
+    int x, y;
+    TXT_GetXY(&x, &y);
+    return y;
+}
+
+//
+// D_SetCursorPosition
+//
+static void D_SetCursorPosition(int column, int row)
+{
+    TXT_GotoXY(column, row);
+}
+
+//
+// D_SetChar
+//
+static void D_SetChar(char c)
+{
+    int x, y;
+    // Backup position
+    TXT_GetXY(&x, &y);
+    TXT_PutChar(c);
+    // Restore position
+    TXT_GotoXY(x, y);
+}
+
+//
+// D_DrawText
+//
+static void D_DrawText(char *string, int bc, int fc)
+{
+    int column;
+    int row;
+    int i;
+
+    if (!using_text_startup)
+    {
+        return;
+    }
+
+    // Set text color
+    TXT_BGColor(bc, 0);
+    TXT_FGColor(fc);
+
+    // Get column position
+    column = D_GetCursorColumn();
+
+    // Get row position
+    row = D_GetCursorRow();
+
+    for (i = 0; i < strlen(string); i++)
+    {
+        // Set character
+        D_SetChar(string[i]);
+
+        // Check cursor position
+        if (++column >= 80)
+            column = 0;
+
+        // Set postition
+        D_SetCursorPosition(column, row);
+    }
+}
+
 //=============================================================================
 //
 // haleyjd: Chocolate Strife Specifics
@@ -1167,11 +1268,20 @@ static void D_IntroBackground(void)
 
 static void D_InitIntroSequence(void)
 {
+    byte *textScreen;
+    char string[80];
+
+    if (devparm || !graphical_startup || testcontrols)
+    {
+        using_text_startup = false;
+        showintro = false;
+        return;
+    }
+
     if(showintro)
     {
         // In vanilla Strife, Mode 13h was initialized directly in D_DoomMain.
         // We have to be a little more courteous of the low-level code here.
-        I_SetWindowTitle(gamedescription);
         I_SetGrabMouseCallback(D_StartupGrabCallback);
         I_InitGraphics();
         V_RestoreBuffer(); // make the V_ routines work
@@ -1188,22 +1298,62 @@ static void D_InitIntroSequence(void)
 
         // Draw the background
         D_IntroBackground();
+
+        using_text_startup = false;
     }
-    /*
-    // STRIFE-FIXME: This was actually displayed on a special textmode
-    // screen with ANSI color codes... would require use of textlib to
-    // emulate properly...
     else
     {
-        puts(DEH_String("Conversation ON"));
-        puts(DEH_String("Rogue Entertainment"));
-        puts(DEH_String("and"));
-        puts(DEH_String("Velocity Games"));
-        puts(DEH_String("present"));
-        puts(DEH_String("S T R I F E"));
-        puts(DEH_String("Loading..."));
+        if (!TXT_Init())
+        {
+            using_text_startup = false;
+            return;
+        }
+
+        I_InitWindowTitle();
+        I_InitWindowIcon();
+
+        // Clear screen
+        textScreen = TXT_GetScreenData();
+        memset(textScreen, 0, 4000);
+
+        using_text_startup = true;
+
+        // Print title
+
+        D_SetCursorPosition(0, 0);
+        D_DrawText(title, TXT_COLOR_GREEN, TXT_COLOR_BLACK);
+
+        DEH_snprintf(string, sizeof(string), "Rogue Entertainment");
+        D_SetCursorPosition(40 - strlen(string) / 2, 5);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        DEH_snprintf(string, sizeof(string), "and");
+        D_SetCursorPosition(40 - strlen(string) / 2, 7);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        DEH_snprintf(string, sizeof(string), "Velocity Games");
+        D_SetCursorPosition(40 - strlen(string) / 2, 9);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        DEH_snprintf(string, sizeof(string), "present");
+        D_SetCursorPosition(40 - strlen(string) / 2, 11);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        DEH_snprintf(string, sizeof(string), "S T R I F E");
+        D_SetCursorPosition(40 - strlen(string) / 2, 14);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        DEH_snprintf(string, sizeof(string), "Loading...");
+        D_SetCursorPosition(40 - strlen(string) / 2, 17);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        DEH_snprintf(string, sizeof(string),
+                    "[                                                  ]");
+        D_SetCursorPosition(14, 18);
+        D_DrawText(string, TXT_COLOR_BLUE, TXT_COLOR_GREEN);
+
+        TXT_UpdateScreen();
     }
-    */
 }
 
 //
@@ -1216,41 +1366,62 @@ static void D_DrawIntroSequence(void)
 {
     int laserpos;
     int robotpos;
+    int i;
 
-    if(!showintro)
-        return;
+    if (showintro)
+    {
+        D_IntroBackground(); // haleyjd: refresh the background
 
-    D_IntroBackground(); // haleyjd: refresh the background
+        // Laser position
+        laserpos = (200 * introprogress / MAXINTROPROGRESS) + 60;
 
-    // Laser position
-    laserpos = (200 * introprogress / MAXINTROPROGRESS) + 60;
+        // BUG: (?) Due to this clip, the laser never even comes close to
+        // touching the peasant; confirmed with vanilla. This MAY have been
+        // intentional, for effect, however, since no death frames are shown 
+        // either... kind of a black-out death.
+        if (laserpos > 200)
+            laserpos = 200;
 
-    // BUG: (?) Due to this clip, the laser never even comes close to
-    // touching the peasant; confirmed with vanilla. This MAY have been
-    // intentional, for effect, however, since no death frames are shown 
-    // either... kind of a black-out death.
-    if(laserpos > 200)
-        laserpos = 200;
+        // Draw the laser
+        // Blitted 16 bytes for 16 rows starting at 705280 + laserpos
+        // (705280 - 0xA0000) / 320 == 156
+        V_DrawBlock(laserpos, 156, 16, 16, rawgfx_startlz[laserpos % 2]);
 
-    // Draw the laser
-    // Blitted 16 bytes for 16 rows starting at 705280 + laserpos
-    // (705280 - 0xA0000) / 320 == 156
-    V_DrawBlock(laserpos, 156, 16, 16, rawgfx_startlz[laserpos % 2]);
+        // Robot position
+        robotpos = laserpos % 5 - 2;
 
-    // Robot position
-    robotpos = laserpos % 5 - 2;
+        // Draw the robot
+        // Blitted 48 bytes for 48 rows starting at 699534 + (320*robotpos)
+        // 699534 - 0xA0000 == 44174, which % 320 == 14, / 320 == 138
+        V_DrawBlock(14, 138 + robotpos, 48, 48, rawgfx_startbot);
 
-    // Draw the robot
-    // Blitted 48 bytes for 48 rows starting at 699534 + (320*robotpos)
-    // 699534 - 0xA0000 == 44174, which % 320 == 14, / 320 == 138
-    V_DrawBlock(14, 138 + robotpos, 48, 48, rawgfx_startbot);
+        // Draw the peasant
+        // Blitted 32 bytes for 64 rows starting at 699142
+        // 699142 - 0xA0000 == 43782, which % 320 == 262, / 320 == 136
+        V_DrawBlock(262, 136, 32, 64, rawgfx_startp[laserpos % 4]);
 
-    // Draw the peasant
-    // Blitted 32 bytes for 64 rows starting at 699142
-    // 699142 - 0xA0000 == 43782, which % 320 == 262, / 320 == 136
-    V_DrawBlock(262, 136, 32, 64, rawgfx_startp[laserpos % 4]);
+        I_FinishUpdate();
+    }
+    else if (using_text_startup)
+    {
+        // Laser position
+        laserpos = 50 * introprogress / MAXINTROPROGRESS;
 
-    I_FinishUpdate();
+        if (laserpos > 50)
+        {
+            laserpos = 50;
+        }
+
+        for (i = 0; i < laserpos; i++)
+        {
+            D_SetCursorPosition(15 + i, 18);
+            D_DrawText("#", TXT_COLOR_GREEN, TXT_COLOR_BLUE);
+        }
+
+        I_Sleep(10);
+
+        TXT_UpdateScreen();
+    }
 }
 
 //
@@ -1343,7 +1514,6 @@ void D_DoomMain (void)
     //DEH_printf("Z_Init: Init zone memory allocation daemon. \n"); [STRIFE] removed
     Z_Init ();
 
-#ifdef FEATURE_MULTIPLAYER
     //!
     // @category net
     //
@@ -1400,8 +1570,6 @@ void D_DoomMain (void)
         exit(0);
     }
 
-#endif
-
     //!
     // @vanilla
     //
@@ -1539,11 +1707,6 @@ void D_DoomMain (void)
     D_BindVariables();
     M_LoadDefaults();
 
-    if (!graphical_startup)
-    {
-        showintro = false;
-    }
-
     // Save configuration at exit.
     I_AtExit(M_SaveDefaults, false);
 
@@ -1563,11 +1726,10 @@ void D_DoomMain (void)
         DEH_printf("W_Init: Init WADfiles.\n");
     D_AddFile(iwadfile);
     W_CheckCorrectIWAD(strife);
+    D_IdentifyVersion();
 
-#ifdef FEATURE_DEHACKED
     // Load dehacked patches specified on the command line.
     DEH_ParseCommandLine();
-#endif
 
     // Load PWAD files.
     modifiedgame = W_ParseCommandLine();
@@ -1654,10 +1816,11 @@ void D_DoomMain (void)
     // Generate the WAD hash table.  Speed things up a bit.
 
     W_GenerateHashTable();
-    
-    D_IdentifyVersion();
+
     InitGameVersion();
+    InitTitleString();
     D_SetGameDescription();
+    I_SetWindowTitle(gamedescription);
     savegamedir = M_GetSaveGameDir("strife1.wad");
 
     // fraggle 20130405: I_InitTimer is needed here for the netgame
@@ -1666,11 +1829,9 @@ void D_DoomMain (void)
     I_InitSound(true);
     I_InitMusic();
 
-#ifdef FEATURE_MULTIPLAYER
     if(devparm) // [STRIFE]
         printf ("NET_Init: Init network subsystem.\n");
     NET_Init();
-#endif
     D_ConnectNetGame();
 
     // haleyjd 20110210: Create Strife hub save folders
@@ -1985,5 +2146,10 @@ void D_DoomMain (void)
             D_StartTitle ();                // start up intro loop
     }
 
+    if (using_text_startup)
+    {
+        TXT_Shutdown();
+    }
+
     D_DoomLoop ();  // never returns
 }
