@@ -29,6 +29,7 @@
 #include "d_main.h"
 #include "deh_main.h"
 
+#include "i_input.h"
 #include "i_swap.h"
 #include "i_system.h"
 #include "i_timer.h"
@@ -752,9 +753,16 @@ void M_DoSave(int slot)
 //
 void M_SaveSelect(int choice)
 {
+    int x, y;
+
     // we are going to be intercepting all chars
     saveStringEnter = 1;
 
+    // We need to turn on text input:
+    x = LoadDef.x - 11;
+    y = LoadDef.y + choice * LINEHEIGHT - 4;
+    I_StartTextInput(x, y, x + 8 + 24 * 8 + 8, y + LINEHEIGHT - 2);
+
     // [STRIFE]
     quickSaveSlot = choice;
     //saveSlot = choice;
@@ -1849,6 +1857,7 @@ boolean M_Responder (event_t* ev)
 
         case KEY_ESCAPE:
             saveStringEnter = 0;
+            I_StopTextInput();
             M_StringCopy(savegamestrings[quickSaveSlot], saveOldString,
                          sizeof(savegamestrings[quickSaveSlot]));
             break;
@@ -1856,6 +1865,7 @@ boolean M_Responder (event_t* ev)
         case KEY_ENTER:
             // [STRIFE]
             saveStringEnter = 0;
+            I_StopTextInput();
             if(gameversion == exe_strife_1_31 && !namingCharacter)
             {
                // In 1.31, we can be here as a result of normal saving again,
@@ -1869,16 +1879,26 @@ boolean M_Responder (event_t* ev)
             break;
 
         default:
-            // This is complicated.
+            // Savegame name entry. This is complicated.
             // Vanilla has a bug where the shift key is ignored when entering
             // a savegame name. If vanilla_keyboard_mapping is on, we want
-            // to emulate this bug by using 'data1'. But if it's turned off,
-            // it implies the user doesn't care about Vanilla emulation: just
-            // use the correct 'data2'.
+            // to emulate this bug by using ev->data1. But if it's turned off,
+            // it implies the user doesn't care about Vanilla emulation:
+            // instead, use ev->data3 which gives the fully-translated and
+            // modified key input.
+
+            if (ev->type != ev_keydown)
+            {
+                break;
+            }
 
             if (vanilla_keyboard_mapping)
             {
-                ch = key;
+                ch = ev->data1;
+            }
+            else
+            {
+                ch = ev->data3;
             }
 
             ch = toupper(ch);
