@@ -35,21 +35,21 @@
 
 #include "w_wad.h"
 
-typedef struct
+typedef PACKED_STRUCT (
 {
     // Should be "IWAD" or "PWAD".
     char		identification[4];
     int			numlumps;
     int			infotableofs;
-} PACKEDATTR wadinfo_t;
+}) wadinfo_t;
 
 
-typedef struct
+typedef PACKED_STRUCT (
 {
     int			filepos;
     int			size;
     char		name[8];
-} PACKEDATTR filelump_t;
+}) filelump_t;
 
 //
 // GLOBALS
@@ -206,13 +206,7 @@ wad_file_t *W_AddFile (char *filename)
 
     startlump = numlumps;
     numlumps += numfilelumps;
-    lumpinfo = realloc(lumpinfo, numlumps * sizeof(lumpinfo_t *));
-    if (lumpinfo == NULL)
-    {
-        W_CloseFile(wad_file);
-        I_Error("Failed to increase lumpinfo[] array size.");
-    }
-
+    lumpinfo = I_Realloc(lumpinfo, numlumps * sizeof(lumpinfo_t *));
     filerover = fileinfo;
 
     for (i = startlump; i < numlumps; ++i)
